@@ -1,6 +1,6 @@
 import numpy as np
 import random
-
+import matplotlib.pyplot as plt
 
 class PoissonGenerator(object):
     """
@@ -17,8 +17,12 @@ class PoissonGenerator(object):
         if shape is None or len(shape) != 2:
             raise AttributeError("当前版本仅支持 2d mask，请检查 shape")
         self.shape = shape
+        if self.shape[0] <= 2 or self.shape[1] <= 2:
+            raise ValueError("shape太小")
         self.min_shape = min(shape)
         self.min_distance = min_distance
+        if self.min_distance <= 1:
+            raise ValueError("距离太小")
         self.max_distance = max_distance
         self.search_times = search_times
         if self.max_distance == 0 or self.max_distance <= self.min_distance:
@@ -59,3 +63,12 @@ class PoissonGenerator(object):
         s = list(mask.flatten()).count(1)
         self.sample_rate = s / (self.shape[0] * self.shape[1])
         return mask
+
+if __name__ == '__main__':
+    shape = (256, 512)
+    rg = PoissonGenerator(shape, min_distance=10)
+    mask = rg.mask2d()
+    print(rg.sample_rate)
+
+    plt.imshow(mask, cmap="gray")
+    plt.show()
\ No newline at end of file
